==> openshift-model-operator-5.8.1-sources.jar: io/fabric8/openshift/api/model/operator/v1/DNSStatusFluent.java <==
package io.fabric8.openshift.api.model.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface DNSStatusFluent<A extends io.fabric8.openshift.api.model.operator.v1.DNSStatusFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  public java.lang.String getClusterDomain();
  public A withClusterDomain(java.lang.String clusterDomain);
  public java.lang.Boolean hasClusterDomain();
  
  /**
   * Method is deprecated. use withClusterDomain instead.
   */
  @java.lang.Deprecated
  public A withNewClusterDomain(java.lang.String arg0);
  public java.lang.String getClusterIP();
  public A withClusterIP(java.lang.String clusterIP);
  public java.lang.Boolean hasClusterIP();
  
  /**
   * Method is deprecated. use withClusterIP instead.
   */
  @java.lang.Deprecated
  public A withNewClusterIP(java.lang.String arg0);
  public A addToConditions(java.lang.Integer index,io.fabric8.openshift.api.model.operator.v1.OperatorCondition item);
  public A setToConditions(java.lang.Integer index,io.fabric8.openshift.api.model.operator.v1.OperatorCondition item);
  public A addToConditions(io.fabric8.openshift.api.model.operator.v1.OperatorCondition... items);
  public A addAllToConditions(java.util.Collection<io.fabric8.openshift.api.model.operator.v1.OperatorCondition> items);
  public A removeFromConditions(io.fabric8.openshift.api.model.operator.v1.OperatorCondition... items);
  public A removeAllFromConditions(java.util.Collection<io.fabric8.openshift.api.model.operator.v1.OperatorCondition> items);
  public A removeMatchingFromConditions(java.util.function.Predicate<io.fabric8.openshift.api.model.operator.v1.OperatorConditionBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildConditions instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public java.util.List<io.fabric8.openshift.api.model.operator.v1.OperatorCondition> getConditions();
  public java.util.List<io.fabric8.openshift.api.model.operator.v1.OperatorCondition> buildConditions();
  public io.fabric8.openshift.api.model.operator.v1.OperatorCondition buildCondition(java.lang.Integer index);
  public io.fabric8.openshift.api.model.operator.v1.OperatorCondition buildFirstCondition();
  public io.fabric8.openshift.api.model.operator.v1.OperatorCondition buildLastCondition();
  public io.fabric8.openshift.api.model.operator.v1.OperatorCondition buildMatchingCondition(java.util.function.Predicate<io.fabric8.openshift.api.model.operator.v1.OperatorConditionBuilder> predicate);
  public java.lang.Boolean hasMatchingCondition(java.util.function.Predicate<io.fabric8.openshift.api.model.operator.v1.OperatorConditionBuilder> predicate);
  public A withConditions(java.util.List<io.fabric8.openshift.api.model.operator.v1.OperatorCondition> conditions);
  public A withConditions(io.fabric8.openshift.api.model.operator.v1.OperatorCondition... conditions);
  public java.lang.Boolean hasConditions();
  public A addNewCondition(java.lang.String lastTransitionTime,java.lang.String message,java.lang.String reason,java.lang.String status,java.lang.String type);
  public io.fabric8.openshift.api.model.operator.v1.DNSStatusFluent.ConditionsNested<A> addNewCondition();
  public io.fabric8.openshift.api.model.operator.v1.DNSStatusFluent.ConditionsNested<A> addNewConditionLike(io.fabric8.openshift.api.model.operator.v1.OperatorCondition item);
  public io.fabric8.openshift.api.model.operator.v1.DNSStatusFluent.ConditionsNested<A> setNewConditionLike(java.lang.Integer index,io.fabric8.openshift.api.model.operator.v1.OperatorCondition item);
  public io.fabric8.openshift.api.model.operator.v1.DNSStatusFluent.ConditionsNested<A> editCondition(java.lang.Integer index);
  public io.fabric8.openshift.api.model.operator.v1.DNSStatusFluent.ConditionsNested<A> editFirstCondition();
  public io.fabric8.openshift.api.model.operator.v1.DNSStatusFluent.ConditionsNested<A> editLastCondition();
  public io.fabric8.openshift.api.model.operator.v1.DNSStatusFluent.ConditionsNested<A> editMatchingCondition(java.util.function.Predicate<io.fabric8.openshift.api.model.operator.v1.OperatorConditionBuilder> predicate);
  public interface ConditionsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.openshift.api.model.operator.v1.OperatorConditionFluent<io.fabric8.openshift.api.model.operator.v1.DNSStatusFluent.ConditionsNested<N>>{
    public N and();
    public N endCondition();
    
  }
  
}

==> openshift-model-operator-5.11.1-sources.jar: io/fabric8/openshift/api/model/operator/v1/DNSStatusFluent.java <==
package io.fabric8.openshift.api.model.operator.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface DNSStatusFluent<A extends io.fabric8.openshift.api.model.operator.v1.DNSStatusFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  public java.lang.String getClusterDomain();
  public A withClusterDomain(java.lang.String clusterDomain);
  public java.lang.Boolean hasClusterDomain();
  
  /**
   * Method is deprecated. use withClusterDomain instead.
   */
  @java.lang.Deprecated
  public A withNewClusterDomain(java.lang.String arg0);
  public java.lang.String getClusterIP();
  public A withClusterIP(java.lang.String clusterIP);
  public java.lang.Boolean hasClusterIP();
  
  /**
   * Method is deprecated. use withClusterIP instead.
   */
  @java.lang.Deprecated
  public A withNewClusterIP(java.lang.String arg0);
  public A addToConditions(java.lang.Integer index,io.fabric8.openshift.api.model.operator.v1.OperatorCondition item);
  public A setToConditions(java.lang.Integer index,io.fabric8.openshift.api.model.operator.v1.OperatorCondition item);
  public A addToConditions(io.fabric8.openshift.api.model.operator.v1.OperatorCondition... items);
  public A addAllToConditions(java.util.Collection<io.fabric8.openshift.api.model.operator.v1.OperatorCondition> items);
  public A removeFromConditions(io.fabric8.openshift.api.model.operator.v1.OperatorCondition... items);
  public A removeAllFromConditions(java.util.Collection<io.fabric8.openshift.api.model.operator.v1.OperatorCondition> items);
  public A removeMatchingFromConditions(java.util.function.Predicate<io.fabric8.openshift.api.model.operator.v1.OperatorConditionBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildConditions instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public java.util.List<io.fabric8.openshift.api.model.operator.v1.OperatorCondition> getConditions();
  public java.util.List<io.fabric8.openshift.api.model.operator.v1.OperatorCondition> buildConditions();
  public io.fabric8.openshift.api.model.operator.v1.OperatorCondition buildCondition(java.lang.Integer index);
  public io.fabric8.openshift.api.model.operator.v1.OperatorCondition buildFirstCondition();
  public io.fabric8.openshift.api.model.operator.v1.OperatorCondition buildLastCondition();
  public io.fabric8.openshift.api.model.operator.v1.OperatorCondition buildMatchingCondition(java.util.function.Predicate<io.fabric8.openshift.api.model.operator.v1.OperatorConditionBuilder> predicate);
  public java.lang.Boolean hasMatchingCondition(java.util.function.Predicate<io.fabric8.openshift.api.model.operator.v1.OperatorConditionBuilder> predicate);
  public A withConditions(java.util.List<io.fabric8.openshift.api.model.operator.v1.OperatorCondition> conditions);
  public A withConditions(io.fabric8.openshift.api.model.operator.v1.OperatorCondition... conditions);
  public java.lang.Boolean hasConditions();
  public A addNewCondition(java.lang.String lastTransitionTime,java.lang.String message,java.lang.String reason,java.lang.String status,java.lang.String type);
  public io.fabric8.openshift.api.model.operator.v1.DNSStatusFluent.ConditionsNested<A> addNewCondition();
  public io.fabric8.openshift.api.model.operator.v1.DNSStatusFluent.ConditionsNested<A> addNewConditionLike(io.fabric8.openshift.api.model.operator.v1.OperatorCondition item);
  public io.fabric8.openshift.api.model.operator.v1.DNSStatusFluent.ConditionsNested<A> setNewConditionLike(java.lang.Integer index,io.fabric8.openshift.api.model.operator.v1.OperatorCondition item);
  public io.fabric8.openshift.api.model.operator.v1.DNSStatusFluent.ConditionsNested<A> editCondition(java.lang.Integer index);
  public io.fabric8.openshift.api.model.operator.v1.DNSStatusFluent.ConditionsNested<A> editFirstCondition();
  public io.fabric8.openshift.api.model.operator.v1.DNSStatusFluent.ConditionsNested<A> editLastCondition();
  public io.fabric8.openshift.api.model.operator.v1.DNSStatusFluent.ConditionsNested<A> editMatchingCondition(java.util.function.Predicate<io.fabric8.openshift.api.model.operator.v1.OperatorConditionBuilder> predicate);
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value);
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public A removeFromAdditionalProperties(java.lang.String key);
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties);
  public java.lang.Boolean hasAdditionalProperties();
  public interface ConditionsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.openshift.api.model.operator.v1.OperatorConditionFluent<io.fabric8.openshift.api.model.operator.v1.DNSStatusFluent.ConditionsNested<N>>{
    public N and();
    public N endCondition();
    
  }
  
}
